define(
//begin v1.x content
({
        nomatchMessage: "Parolalar eşleşmiyor.",
		badPasswordMessage: "Geçersiz Parola."
})

//end v1.x content
);